.. _.readthedocs.yaml-name:

!!!!!!!!!!!!!!!!!
.readthedocs.yaml
!!!!!!!!!!!!!!!!!

.. meta::
   :keywords: .readthedocs.yaml, read, docs, configuration

.. index:: .readthedocs.yaml, read, docs, configuration

.. _.readthedocs.yaml-title:

Example Read the Docs Configuration
###################################

.. contents::
   :local:

.. _.readthedocs.yaml@This Example File:

This Example File
*****************

.. literalinclude:: ../../.readthedocs.yaml
   :language: yaml
